/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                TERCER GRADO DE PREESCOLAR (Excale 00)
/*
/*                       **** PENSAMIENTO MATEMATICO ****
/*
/*                     Ciclo escolar evaluado: 2006 - 2007
/*_____________________________________________________________________________
/*
/*
/*       PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE PENSAMIENTO
/*                           MATEMATICO EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte el archivo Excale00_2007_Alum_PM.txt el cual est en
/*  formato ASCII a una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale00_2007_Alum_PM.txt
/*         as como el archivo Excale00_2007_Alum_PM.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale00_2007_Alum_PM.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale00_2007_Alum_PM.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 5 DE AGOSTO DE 2008
/*
/*  ****************************************************************************/


LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale00_2007_Alum_PM.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbano Pblico"
                       2         ="Rural Pblico"
                       3         ="Educacin Indgena"
                       4         ="Cursos Comunitarios"
                       5         ="Privados";
     VALUE $modF       "UP"      ="Urbano Pblico"
                       "RP"      ="Rural Pblico"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privados";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadF       99        ="Respuesta omitida";
     VALUE edadcF      1         ="Cuatro aos o menos"
                       2         ="Cinco aos"
                       3         ="Seis aos"
                       4         ="Siete aos o ms"
                       9         ="Respuesta omitida";
     VALUE edad1sF     99        ="Respuesta omitida";
     VALUE edad1scF    1         ="Cuatro aos o menos"
                       2         ="Cinco aos"
                       3         ="Seis o ms aos"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE mes_nacF    1         ="Enero"
                       2         ="Febrero"
                       3         ="Marzo"
                       4         ="Abril"
                       5         ="Mayo"
                       6         ="Junio"
                       7         ="Julio"
                       8         ="Agosto"
                       9         ="Septiembre"
                       10        ="Octubre"
                       11        ="Noviembre"
                       12        ="Diciembre"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE docenteF    99999     ="Respuesta omitida";
     VALUE ema1_13F
                       0         ="Fallo"
                       1         ="Acierto (pregunta dicotmica)/Acierto parcial (Pregunta politmica)"
                       2         ="Acierto total (pregunta dicotmica)"
                       5         ="Respuesta invlida, el alumno no respondi lo que se esperaba"
                       7         ="Reactivo no administrado (No se incluy en su cuadernillo de examen)"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
RUN;



DATA INEE.Excale00_2007_Alum_PM;
   LENGTH
       nacional           3
       escuela            4
       id_ent             3
       nom_ent            $19
       id_mod             3
       mod                $4
       entest             $6
       alumno             6
       id_instr           $15
       sexo               3
       edad               8
       edadc              3
       edad1sep           8
       edad1sepc          3
       edadn              3
       edad_ac            3
       mes_nac            3
       w_alu              8
       docente            5
       ema_01             3
       ema_02             3
       ema_03             3
       ema_04             3
       ema_05             3
       ema_06             3
       ema_07             3
       ema_08             3
       ema_09             3
       ema_10             3
       ema_11             3
       ema_12             3
       ema_13             3
       ema_14             3
       emb_01             3
       emb_02             3
       emb_03             3
       emb_04             3
       emb_05_01          3
       emb_05_02          3
       emb_05_03          3
       emb_05_04          3
       emb_05_05          3
       emb_06             3
       emb_07             3
       emb_08_02          3
       emb_08_03          3
       emb_08_04          3
       emb_09             3
       emb_10             3
       emb_11             3
       emb_12             3
       emb_13             3
       emc_01             3
       emc_02             3
       emc_03             3
       emc_04             3
       emc_05             3
       emc_06             3
       emc_07             3
       emc_08             3
       emc_09             3
       emc_10             3
       emc_11             3
       emc_12             3
       emc_13             3
       emc_14             3
       emd_01             3
       emd_02             3
       emd_03             3
       emd_04             3
       emd_05_01          3
       emd_05_02          3
       emd_05_03          3
       emd_05_04          3
       emd_06             3
       emd_07             3
       emd_08             3
       emd_09             3
       emd_10             3
       emd_11             3
       emd_12             3
       emd_13             3
       pv1Mat             8
       pv2Mat             8
       pv3Mat             8
       pv4Mat             8
       pv5Mat             8
       Matnvl1            3
       Matnvl2            3
       Matnvl3            3
       Matnvl4            3
       Matnvl5            3
       Matnvlb1           3
       Matnvlb2           3
       Matnvlb3           3
       Matnvlb4           3
       Matnvlb5           3
       wvarstrr           3
       w_fstr1            8
       w_fstr2            8
       w_fstr3            8
       w_fstr4            8
       w_fstr5            8
       w_fstr6            8
       w_fstr7            8
       w_fstr8            8
       w_fstr9            8
       w_fstr10           8
       w_fstr11           8
       w_fstr12           8
       w_fstr13           8
       w_fstr14           8
       w_fstr15           8
       w_fstr16           8
       w_fstr17           8
       w_fstr18           8
       w_fstr19           8
       w_fstr20           8
       w_fstr21           8
       w_fstr22           8
       w_fstr23           8
       w_fstr24           8
       w_fstr25           8
       w_fstr26           8
       w_fstr27           8
       w_fstr28           8
       w_fstr29           8
       w_fstr30           8
       w_fstr31           8
       w_fstr32           8
       w_fstr33           8
       w_fstr34           8
       w_fstr35           8
       w_fstr36           8
       w_fstr37           8
       w_fstr38           8
       w_fstr39           8
       w_fstr40           8
       w_fstr41           8
       w_fstr42           8
       w_fstr43           8
       w_fstr44           8
       w_fstr45           8
       w_fstr46           8
       w_fstr47           8
       w_fstr48           8
       w_fstr49           8
       w_fstr50           8
       w_fstr51           8
       w_fstr52           8
       w_fstr53           8
       w_fstr54           8
       w_fstr55           8
       w_fstr56           8
       w_fstr57           8
       w_fstr58           8
       w_fstr59           8
       w_fstr60           8
       w_fstr61           8
       w_fstr62           8
       w_fstr63           8
       w_fstr64           8
       w_fstr65           8
       w_fstr66           8
       w_fstr67           8
       w_fstr68           8
       w_fstr69           8
       w_fstr70           8
       w_fstr71           8
       w_fstr72           8
       w_fstr73           8
       w_fstr74           8
       w_fstr75           8
       w_fstr76           8
       w_fstr77           8
       w_fstr78           8
       w_fstr79           8
       w_fstr80           8
   ;

INFILE alum MISSOVER LINESIZE = 1113;
   INPUT
        nacional              1 - 1
        escuela               2 - 5
        id_ent                6 - 7
        nom_ent               8 - 26
        id_mod               27 - 27
        mod                  28 - 31
        entest               32 - 37
        alumno               38 - 42
        id_instr             43 - 57
        sexo                 58 - 58
        EDAD                 59 - 69
        EDADC                70 - 70
        Edad1sep             71 - 81
        Edad1SepC            82 - 82
        EDADN                83 - 83
        edad_ac              84 - 85
        mes_nac              86 - 87
        w_alu                88 - 98
        docente              99 - 103
        ema_01              104 - 104
        ema_02              105 - 105
        ema_03              106 - 106
        ema_04              107 - 107
        ema_05              108 - 108
        ema_06              109 - 109
        ema_07              110 - 110
        ema_08              111 - 111
        ema_09              112 - 112
        ema_10              113 - 113
        ema_11              114 - 114
        ema_12              115 - 115
        ema_13              116 - 116
        ema_14              117 - 117
        emb_01              118 - 118
        emb_02              119 - 119
        emb_03              120 - 120
        emb_04              121 - 121
        emb_05_01           122 - 122
        emb_05_02           123 - 123
        emb_05_03           124 - 124
        emb_05_04           125 - 125
        emb_05_05           126 - 126
        emb_06              127 - 127
        emb_07              128 - 128
        emb_08_02           129 - 129
        emb_08_03           130 - 130
        emb_08_04           131 - 131
        emb_09              132 - 132
        emb_10              133 - 133
        emb_11              134 - 134
        emb_12              135 - 135
        emb_13              136 - 136
        emc_01              137 - 137
        emc_02              138 - 138
        emc_03              139 - 139
        emc_04              140 - 140
        emc_05              141 - 141
        emc_06              142 - 142
        emc_07              143 - 143
        emc_08              144 - 144
        emc_09              145 - 145
        emc_10              146 - 146
        emc_11              147 - 147
        emc_12              148 - 148
        emc_13              149 - 149
        emc_14              150 - 150
        emd_01              151 - 151
        emd_02              152 - 152
        emd_03              153 - 153
        emd_04              154 - 154
        emd_05_01           155 - 155
        emd_05_02           156 - 156
        emd_05_03           157 - 157
        emd_05_04           158 - 158
        emd_06              159 - 159
        emd_07              160 - 160
        emd_08              161 - 161
        emd_09              162 - 162
        emd_10              163 - 163
        emd_11              164 - 164
        emd_12              165 - 165
        emd_13              166 - 166
        pv1Mat              167 - 177
        pv2Mat              178 - 188
        pv3Mat              189 - 199
        pv4Mat              200 - 210
        pv5Mat              211 - 221
        Matnvl1             222 - 222
        Matnvl2             223 - 223
        Matnvl3             224 - 224
        Matnvl4             225 - 225
        Matnvl5             226 - 226
        Matnvlb1            227 - 227
        Matnvlb2            228 - 228
        Matnvlb3            229 - 229
        Matnvlb4            230 - 230
        Matnvlb5            231 - 231
        wvarstrr            232 - 233
        w_fstr1             234 - 244
        w_fstr2             245 - 255
        w_fstr3             256 - 266
        w_fstr4             267 - 277
        w_fstr5             278 - 288
        w_fstr6             289 - 299
        w_fstr7             300 - 310
        w_fstr8             311 - 321
        w_fstr9             322 - 332
        w_fstr10            333 - 343
        w_fstr11            344 - 354
        w_fstr12            355 - 365
        w_fstr13            366 - 376
        w_fstr14            377 - 387
        w_fstr15            388 - 398
        w_fstr16            399 - 409
        w_fstr17            410 - 420
        w_fstr18            421 - 431
        w_fstr19            432 - 442
        w_fstr20            443 - 453
        w_fstr21            454 - 464
        w_fstr22            465 - 475
        w_fstr23            476 - 486
        w_fstr24            487 - 497
        w_fstr25            498 - 508
        w_fstr26            509 - 519
        w_fstr27            520 - 530
        w_fstr28            531 - 541
        w_fstr29            542 - 552
        w_fstr30            553 - 563
        w_fstr31            564 - 574
        w_fstr32            575 - 585
        w_fstr33            586 - 596
        w_fstr34            597 - 607
        w_fstr35            608 - 618
        w_fstr36            619 - 629
        w_fstr37            630 - 640
        w_fstr38            641 - 651
        w_fstr39            652 - 662
        w_fstr40            663 - 673
        w_fstr41            674 - 684
        w_fstr42            685 - 695
        w_fstr43            696 - 706
        w_fstr44            707 - 717
        w_fstr45            718 - 728
        w_fstr46            729 - 739
        w_fstr47            740 - 750
        w_fstr48            751 - 761
        w_fstr49            762 - 772
        w_fstr50            773 - 783
        w_fstr51            784 - 794
        w_fstr52            795 - 805
        w_fstr53            806 - 816
        w_fstr54            817 - 827
        w_fstr55            828 - 838
        w_fstr56            839 - 849
        w_fstr57            850 - 860
        w_fstr58            861 - 871
        w_fstr59            872 - 882
        w_fstr60            883 - 893
        w_fstr61            894 - 904
        w_fstr62            905 - 915
        w_fstr63            916 - 926
        w_fstr64            927 - 937
        w_fstr65            938 - 948
        w_fstr66            949 - 959
        w_fstr67            960 - 970
        w_fstr68            971 - 981
        w_fstr69            982 - 992
        w_fstr70            993 - 1003
        w_fstr71           1004 - 1014
        w_fstr72           1015 - 1025
        w_fstr73           1026 - 1036
        w_fstr74           1037 - 1047
        w_fstr75           1048 - 1058
        w_fstr76           1059 - 1069
        w_fstr77           1070 - 1080
        w_fstr78           1081 - 1091
        w_fstr79           1092 - 1102
        w_fstr80           1103 - 1113
;

   LABEL
       nacional    = "Variable auxiliar para obtener promedios nacionales"
       escuela     = "Identificador de la escuela"
       id_ent      = "Entidad federativa (identificador numrico)"
       nom_ent     = "Entidad federativa"
       id_mod      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       mod         = "Estrato escolar o Modalidad educativa"
       entest      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad-Densidad de poblacin)"
       alumno      = "Identificador del alumno"
       id_instr    = "Identificador del cuadernillo de examen"
       sexo        = "Sexo del alumno"
       EDAD        = "Edad del alumno al mes de mayo de 2007, en aos (al momento de la aplicacin)"
       EDADC       = "Edad del alumno al mes de mayo de 2007, codificada (al momento de la aplicacin)"
       Edad1sep    = "Edad del alumno al mes de septiembre de 2006, en aos (al inicio del ciclo escolar)"
       Edad1SepC   = "Edad del alumno al mes de septiembre de 2006, codificada (al inicio del ciclo escolar)"
       EDADN       = "Edad normativa"
       edad_ac     = "Edad en aos cumplidos (al momento de la aplicacin)"
       mes_nac     = "Mes de nacimiento del alumno"
       w_alu       = "Peso muestral o ponderador del alumno"
       docente     = "Identificador del docente que imparte clases al alumno"
       ema_01      ="Identifica la cantidad de elementos en colecciones de objetos de la misma clase, de trece a veinte objetos, ordenados en una lnea."
       ema_02      ="Identifica la cantidad de elementos en colecciones de objetos de distinta clase, de siete a doce objetos, ordenados."
       ema_03      ="Enumera de manera oral objetos desde el uno y hasta el que sabe (sabe al menos 20, y mximo 30 ) siguiendo el orden de la serie numrica."
       ema_04      ="Identifica el lugar que ocupa una persona o un objeto dentro de una serie ordenada."
       ema_05      ="Identifica el orden de los nmeros en forma escrita."
       ema_06      ="Resuelve problemas que implican reunir objetos en una sola coleccin."
       ema_07      ="Resuelve problemas que implican igualar cantidades de dos colecciones que contienen elementos de la misma clase."
       ema_08      ="Interpreta  informacin registrada en cuadros y tablas."
       ema_09      ="Ordena de manera creciente o decreciente objetos por tamao."
       ema_10      ="Anticipa los cambios que ocurren en una figura geomtrica al cortarla."
       ema_11      ="Identifica desplazamientos de objetos con respecto a otros objetos. Direccionalidad con interioridad o con orientacin."
       ema_12      ="Identifica cmo se ven objetos desde diversos puntos espaciales: arriba, abajo, lejos, cerca, de frente y de perfil, de espaldas."
       ema_13      ="Realiza estimaciones sobre las caractersticas medibles de sujetos, objetos y espacios."
       ema_14      ="Distingue el instrumento  apropiado para medir peso."
       emb_01      ="Identifica la cantidad de elementos en colecciones de objetos de la misma clase de siete a doce objetos, ordenados en un arreglo rectangular."
       emb_02      ="Identifica la cantidad de elementos en colecciones de objetos de distinta clase, de siete a doce objetos, desordenados."
       emb_03      ="Compara colecciones y establece relaciones en situaciones de desigualdad. Identificando donde hay menos elementos."
       emb_04      ="Identifica el valor de las monedas."
       emb_05_01   ="Escribe nmeros que le son dictados. (Nmero menor que tres)."
       emb_05_02   ="Escribe nmeros que le son dictados. (Nmero mayor que dos y menor que seis)."
       emb_05_03   ="Escribe nmeros que le son dictados. (Nmero mayor que cinco y menor que diez)."
       emb_05_04   ="Escribe nmeros que le son dictados. (Nmero mayor que nueve y menor que veinte)."
       emb_05_05   ="Escribe nmeros que le son dictados. (Nmero mayor que diecinueve y menor que treinta)."
       emb_06      ="Resuelve problemas que implican comparar la cantidad de dos colecciones."
       emb_07      ="Resuelve problemas que implican repartir objetos."
       emb_08_02   ="Registra informacin respecto a un solo elemento en grficas sencillas."
       emb_08_03   ="Registra informacin de ms de un elemento en grficas sencillas."
       emb_08_04   ="Registra correctamente en grficas sencillas informacin de objetos que son ms pequeos y a la vez ms numerosos que otros elementos."
       emb_09      ="Identifica la coleccin que sigue en una serie de colecciones."
       emb_10      ="Identifica los cambios que ocurren en una figura geomtrica al combinarla con otras iguales o diferentes."
       emb_11      ="Identifica posiciones de objetos con respecto a otros objetos. Orientacin e interioridad."
       emb_12      ="Resuelve problemas que impliquen medir longitudes."
       emb_13      ="Establece relaciones temporales (antes-despus-al final)."
       emc_01      ="Identifica la cantidad de elementos en colecciones de objetos de distinta clase, de trece a veinte objetos, ordenados."
       emc_02      ="Compara colecciones y establece relaciones de igualdad."
       emc_03      ="Resuelve problemas que implican usar la equivalencia del valor de las monedas."
       emc_04      ="Distingue todos los nmeros de las letras en un texto."
       emc_05      ="Escribe los nmeros que sabe en orden ascendente, sin equivocarse, empezando desde uno y llegando a un rango entre 31 y 89."
       emc_06      ="Resuelve problemas que implican quitar objetos a una coleccin."
       emc_07      ="Identifica patrones no numricos."
       emc_08      ="Identifica la coleccin faltante en una serie de colecciones."
       emc_09      ="Identifica ms de una de tres figuras semejantes a una muestra."
       emc_10      ="Identifica tres o ms, de cinco figuras geomtricas a partir de solicitarle que identifique todas las que tienen un nmero determinado de lados del mismo tamao."
       emc_11      ="Identifica posiciones de objetos con respecto a otros objetos. Orientacin y proximidad."
       emc_12      ="Identifica posiciones de objetos con respecto a otros objetos.  Interioridad y proximidad."
       emc_13      ="Estima el nmero exacto de veces que cabe la longitud de un objeto pequeo respecto a la longitud de un objeto mas grande."
       emc_14      ="Utiliza correctamente los das de la semana."
       emd_01      ="Identifica la cantidad de elementos en colecciones de objetos de la misma clase, de siete a doce objetos, desordenados."
       emd_02      ="Compara colecciones y establece relaciones en situaciones de desigualdad, identificando donde hay mas elementos."
       emd_03      ="Dice los nmeros que sabe en orden ascendente, sin equivocarse, empezando desde el uno y llegando a un rango de 31 a 89."
       emd_04      ="Identifica usos de los nmeros."
       emd_05_01   ="Utiliza nmeros para representar cantidades menores a siete."
       emd_05_02   ="Utiliza nmeros para representar cantidades mayores a nueve pero menores a trece."
       emd_05_03   ="Utiliza nmeros para representar cantidades mayores a seis pero menores a diez."
       emd_05_04   ="Utiliza nmeros para representar cantidades mayores a trece pero menores a veintiuno"
       emd_06      ="Resuelve problemas que implican agregar."
       emd_07      ="Resuelve problemas que implican igualar cantidades de dos colecciones que contienen elementos de distinta clase."
       emd_08      ="Interpreta informacin registrada en grficas."
       emd_09      ="Ordena de manera creciente objetos por tonalidad."
       emd_10      ="A partir de un cuerpo geomtrico que se le muestra, identifica ms de uno de tres objetos similares en una coleccin de cuerpos geomtricos."
       emd_11      ="Identifica la direccionalidad de un recorrido o trayectoria y sus puntos de referencia."
       emd_12      ="Identifica el objeto que cumple con una condicin medible: ms largo que, ms corto que."
       emd_13      ="Identifica el objeto que cumple con una condicin medible: lleno, vaco."
       pv1Mat      ="Primer valor plausible de Matemticas"
       pv2Mat      ="Segundo valor plausible de Matemticas"
       pv3Mat      ="Tercer valor plausible de Matemticas"
       pv4Mat      ="Cuarto valor plausible de Matemticas"
       pv5Mat      ="Quinto valor plausible de Matemticas"
       Matnvl1     ="Nivel de logro en Matemticas. Asociado a pv1mat. (Cuatro niveles)"
       Matnvl2     ="Nivel de logro en Matemticas. Asociado a pv2mat. (Cuatro niveles)"
       Matnvl3     ="Nivel de logro en Matemticas. Asociado a pv3mat. (Cuatro niveles)"
       Matnvl4     ="Nivel de logro en Matemticas. Asociado a pv4mat. (Cuatro niveles)"
       Matnvl5     ="Nivel de logro en Matemticas. Asociado a pv5mat. (Cuatro niveles)"
       Matnvlb1    ="Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a pv1mat."
       Matnvlb2    ="Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a pv2mat."
       Matnvlb3    ="Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a pv3mat."
       Matnvlb4    ="Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a pv4mat."
       Matnvlb5    ="Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a pv5mat."
       wvarstrr    ="Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       w_fstr1     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr2     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr3     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr4     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr5     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr6     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr7     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr8     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr9     ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr10    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr11    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr12    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr13    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr14    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr15    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr16    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr17    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr18    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr19    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr20    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr21    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr22    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr23    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr24    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr25    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr26    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr27    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr28    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr29    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr30    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr31    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr32    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr33    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr34    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr35    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr36    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr37    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr38    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr39    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr40    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr41    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr42    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr43    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr44    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr45    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr46    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr47    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr48    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr49    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr50    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr51    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr52    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr53    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr54    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr55    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr56    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr57    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr58    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr59    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr60    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr61    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr62    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr63    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr64    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr65    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr66    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr67    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr68    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr69    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr70    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr71    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr72    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr73    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr74    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr75    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr76    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr77    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr78    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr79    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr80    ="Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
   ;

   FORMAT
       nacional           1.
       escuela            4.
       id_ent             id_entF.
       nom_ent            $char19.
       id_mod             id_modF.
       mod                $modF.
       entest             $char6.
       alumno             5.
       id_instr           $char15.
       sexo               sexoF.
       edad               edadF.
       edadc              edadcF.
       edad1sep           edad1sF.
       edad1sepc          edad1scF.
       edadn              edadnF.
       edad_ac            edad_acF.
       mes_nac            mes_nacF.
       docente            docenteF.
       ema_01             ema1_13F.
       ema_02             ema1_13F.
       ema_03             ema1_13F.
       ema_04             ema1_13F.
       ema_05             ema1_13F.
       ema_06             ema1_13F.
       ema_07             ema1_13F.
       ema_08             ema1_13F.
       ema_09             ema1_13F.
       ema_10             ema1_13F.
       ema_11             ema1_13F.
       ema_12             ema1_13F.
       ema_13             ema1_13F.
       ema_14             ema1_13F.
       emb_01             ema1_13F.
       emb_02             ema1_13F.
       emb_03             ema1_13F.
       emb_04             ema1_13F.
       emb_05_01          ema1_13F.
       emb_05_02          ema1_13F.
       emb_05_03          ema1_13F.
       emb_05_04          ema1_13F.
       emb_05_05          ema1_13F.
       emb_06             ema1_13F.
       emb_07             ema1_13F.
       emb_08_02          ema1_13F.
       emb_08_03          ema1_13F.
       emb_08_04          ema1_13F.
       emb_09             ema1_13F.
       emb_10             ema1_13F.
       emb_11             ema1_13F.
       emb_12             ema1_13F.
       emb_13             ema1_13F.
       emc_01             ema1_13F.
       emc_02             ema1_13F.
       emc_03             ema1_13F.
       emc_04             ema1_13F.
       emc_05             ema1_13F.
       emc_06             ema1_13F.
       emc_07             ema1_13F.
       emc_08             ema1_13F.
       emc_09             ema1_13F.
       emc_10             ema1_13F.
       emc_11             ema1_13F.
       emc_12             ema1_13F.
       emc_13             ema1_13F.
       emc_14             ema1_13F.
       emd_01             ema1_13F.
       emd_02             ema1_13F.
       emd_03             ema1_13F.
       emd_04             ema1_13F.
       emd_05_01          ema1_13F.
       emd_05_02          ema1_13F.
       emd_05_03          ema1_13F.
       emd_05_04          ema1_13F.
       emd_06             ema1_13F.
       emd_07             ema1_13F.
       emd_08             ema1_13F.
       emd_09             ema1_13F.
       emd_10             ema1_13F.
       emd_11             ema1_13F.
       emd_12             ema1_13F.
       emd_13             ema1_13F.
       wvarstrr           2.
   ;


/**************************************************************************
/*  Definicin de valores perdidos
/*   .I o I = Respuesta invlida (el alumno no respondi lo que se esperaba).
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;

   ARRAY perdidos1(4)  sexo edadc edad1sepc edadn;
   DO  i=1 TO 4;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(4)  edad edad1sep edad_ac mes_nac;
   DO  i=1 TO 4;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(63)
                   ema_01 ema_02 ema_03 ema_05 ema_05 ema_06 ema_07 ema_08 ema_09
                   ema_10 ema_11 ema_12 ema_13 ema_14 emb_01 emb_02 emb_03 emb_04
                   emb_05_01 emb_05_02 emb_05_03 emb_05_04 emb_05_05 emb_06 emb_07
                   emb_08_02 emb_08_03 emb_08_04 emb_09 emb_10 emb_11 emb_12 emb_13
                   emc_01 emc_02 emc_03 emc_04 emc_05 emc_06 emc_07 emc_08 emc_09
                   emc_10 emc_11 emc_12 emc_13 emc_14 emd_01 emd_02 emd_03 emd_04
                   emd_05_01 emd_05_02 emd_05_03 emd_05_04 emd_06 emd_07 emd_08
                   emd_09 emd_10 emd_11 emd_12 emd_13;
   DO  i=1 TO 63;
          IF perdidos3{i} = 5   THEN  perdidos3{i} = .I;
          IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;

   drop i;
RUN;



